@@ -1,6 +1,10 @@
 
+#ifndef __yelp_marshal_MARSHAL_H__
+#define __yelp_marshal_MARSHAL_H__
+
 #include	<glib-object.h>
 
+G_BEGIN_DECLS
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -50,6 +54,12 @@
 
 
 /* VOID:OBJECT,BOXED (./yelp-marshal.list:1) */
+extern void yelp_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
 void
 yelp_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -87,6 +97,12 @@ yelp_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
 }
 
 /* BOOLEAN:OBJECT (./yelp-marshal.list:2) */
+extern void yelp_marshal_BOOLEAN__OBJECT (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
 void
 yelp_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -125,3 +141,11 @@ yelp_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
+/* VOID:OBJECT,BOXED (yelp-marshal.list:1) */
+
+/* BOOLEAN:OBJECT (yelp-marshal.list:2) */
+
+G_END_DECLS
+
+#endif /* __yelp_marshal_MARSHAL_H__ */
+
